﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Common.Resources;
using HeuristicLab.Scripting;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

namespace HeuristicLab.OptimizationExpertSystem.Menu {
  internal class OpenCSharpScriptMenuItem : MenuItemBase {
    public override Image Image { get { return VSImageLibrary.Open; } }

    public override string Name {
      get { return "Open"; }
    }

    public override IEnumerable<string> Structure {
      get { return new[] { "Tools", "C# Script" }; }
    }

    public override int Position {
      get { return 920; }
    }

    public override string ToolTipText { get { return "Open an existing C# Script."; } }

    public override void Execute() {
      using (var dialog = new OpenFileDialog()) {
        dialog.Filter = "HL Files|*.hl|All Files|*.*";
        if (dialog.ShowDialog(MainForm) != DialogResult.OK) return;
        var script = ContentManager.Load(dialog.FileName) as CSharpScript;
        if (script != null) MainForm.ShowContent(script);
        else MessageBox.Show("HL Files is not a C# script.", "Wrong File", MessageBoxButtons.OK, MessageBoxIcon.Error);
      }
    }
  }
}
